<?php
/**
 * @package     Joomla.Site
 * @subpackage  Templates.protostar
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

/**
 * This is a file to add template specific chrome to module rendering.  To use it you would
 * set the style attribute for the given module(s) include in your template to use the style
 * for each given modChrome function.
 *
 * eg. To render a module mod_test in the submenu style, you would use the following include:
 * <jdoc:include type="module" name="test" style="submenu" />
 *
 * This gives template designers ultimate control over how modules are rendered.
 *
 * NOTICE: All chrome wrapping methods should be named: modChrome_{STYLE} and take the same
 * two arguments.
 */

/*
 * Module chrome for rendering the module in a submenu
 */
function modChrome_no($module, &$params, &$attribs)
{
	if ($module->content)
	{
		echo $module->content;
	}
}

function modChrome_well($module, &$params, &$attribs)
{
	$moduleTag     = $params->get('module_tag', 'div');
	$bootstrapSize = (int) $params->get('bootstrap_size', 0);
	$moduleClass   = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
	$headerTag     = htmlspecialchars($params->get('header_tag', 'h3'));
	$headerClass   = htmlspecialchars($params->get('header_class', 'page-header'));

	if ($module->content)
	{
		echo '<' . $moduleTag . ' class="well ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';

			if ($module->showtitle)
			{
				echo '<' . $headerTag . ' class="' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
			}

			echo $module->content;
		echo '</' . $moduleTag . '>';
	}
}

function modChrome_wellCustom($module, &$params, &$attribs)
{
	$moduleTag     = $params->get('module_tag', 'div');
	$bootstrapSize = (int) $params->get('bootstrap_size', 0);
	$moduleClass   = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
	$headerTag     = htmlspecialchars($params->get('header_tag', 'h3'));

//	var_dump($module->module);

	$moduleClassAdditional = '';

	$iconSuffix = '';
	if($module->module == 'mod_jlms_lpaths'){
		$iconSuffix = 'learning_path';
	}
	if($module->module == 'mod_jlms_quizzes'){
		$iconSuffix = 'quizzes';
	}
	if($module->module == 'mod_jlms_upcoming_webinar'){
		$iconSuffix = 'webinars';
	}
	if($module->module == 'mod_jlms_webinars'){
		$iconSuffix = 'webinars';
	}
	if($module->module == 'mod_jlms_course_teacher'){
		$iconSuffix = 'teacher';
		$moduleClassAdditional = 'teacher';
	}
	if($module->module == 'mod_jlms_course_subscribe'){
		$moduleClassAdditional = 'buy-block';
	}

	if ($module->content)
	{
		echo '<' . $moduleTag . ' class="well clearfix '.$moduleClassAdditional.'">';

		if ($module->showtitle)
		{
			$icon = $iconSuffix ? '<i class="jlmsicon-'.$iconSuffix.'"></i>' : '';
			$dragIcon = '';
			$app = JFactory::getApplication();
			$title = '<span>'.$icon.'<span>'.$module->title.'</span></span>';
			echo '<' . $headerTag . ' class="page-header custom">' . $title . '</' . $headerTag . '>';
		}

		echo '<div class="row-fluid">';
		echo $module->content;
		echo '</div>';

		echo '</' . $moduleTag . '>';
	}
}
?>
