<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 *
 */

namespace LMS\Libraries\Base;

defined('_JEXEC') or die;

use LMS\Libraries\Toolbar;
use LMS\Libraries\ServiceLocator;

/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 * @since       3.1
 */
class View extends \JViewLegacy
{
	/**
	 * @var string dir to view folder. need to be defined in view constructor to successfully load templates
	 */
	protected $viewDir;
	
	protected $widgets = array();
	
	protected $config;
	
	protected $assetsDir;	

	public function __construct($config = array())
	{		
		parent::__construct($config);		
		
		$this->addTemplatePath(JPATH_COMPONENT . DIRECTORY_SEPARATOR . 'templates');		
		$this->addTemplatePath($this->viewDir . DIRECTORY_SEPARATOR . 'tmpl');	
		
		$this->config	= ServiceLocator::get('config');
		$this->assets	= ServiceLocator::get('assets');		
		
	}	
	
	public function widget($name, $params = array(), $uniqueKey = '')	
	{	
		$key = empty($uniqueKey)?$name:$name.$uniqueKey;
		
		if(isset($this->widgets[$key])) {	
			return $this->widgets[$key];
		} else {			
			$params['context']	= $key;			
		
			$className = '\\LMS\\Widgets\\'.ucfirst(strtolower($name));
			$class = new \ReflectionClass($className);			
			
			$this->widgets[$key] = $class->newInstanceArgs(array($params));			
			return $this->widgets[$key];
		}
	}
	
	public function display($tpl = null)
	{	
		$this->addBaseScripts();
		$this->addBaseStyles();			
		
		
		parent::display($tpl);		
	}	
	
	public function addBaseScripts()
	{
		$this->addScript($this->config->get('live_site').'/components/com_joomla_lms/includes/js/jlms_106.js');
	}
	
	public function addBaseStyles()
	{		
		$this->addStyleSheet($this->config->get('live_site').'/components/com_joomla_lms/lms_css/jlms_107.css');
	}	
	/**
	 * Adds a linked script to the page
	 *
	 * @param   string   $url    URL to the linked script
	 * @param   string   $type   Type of script. Defaults to 'text/javascript'
	 * @param   boolean  $defer  Adds the defer attribute.
	 * @param   boolean  $async  Adds the async attribute.
	 *
	 * @return 
	 *	 
	 */
	public function addScript($file, $type = "text/javascript", $defer = false, $async = false)
	{			
		$this->assets->addScript($file, $type, $defer, $async);
	}
	
	public function addScriptDeclaration($content, $type = 'text/javascript')
	{
		$this->assets->addScriptDeclaration($content, $type);
	}
	
	/**
	 * Adds a linked stylesheet to the page
	 *
	 * @param   string  $url      URL to the linked style sheet
	 * @param   string  $type     Mime encoding type
	 * @param   string  $media    Media type that this stylesheet applies to
	 * @param   array   $attribs  Array of attributes
	 *
	 * @return 
	 *	 
	 */
	public function addStyleSheet($file, $type = 'text/css', $media = null, $attribs = array())
	{			
		$this->assets->addStyleSheet($file, $type, $media, $attribs);
	}

	/**
	 * Adds a stylesheet declaration to the page
	 *
	 * @param   string  $content  Style declarations
	 * @param   string  $type     Type of stylesheet (defaults to 'text/css')
	 *
	 * @return 
	 *	 
	 */
	public function addStyleDeclaration($content, $type = 'text/css')
	{
		$this->assets->addStyleDeclaration($content, $type);		
	}	
	
	public function fetchHead() 
	{		
		return $this->assets->fetchHead();		
	}
}