<?php
/**
 * User: nester_a
 * Date: 29.10.13
 */

namespace LMS\Tools\Conference\Repositories;

use LMS\Tools\Conference\Table;
use LMS\Libraries\Base;

class User extends Base\Repository
{
    protected $fieldMap = array(
        'sel_user' => 'user_id',
        'bookedConferenceID' => 'p_id'
    );

	public function __construct($options)
	{
		parent::__construct($options);
		$this->table = new Table\User();
	}

    /**
     * Returns list of user ids who have access to enter specified conference
     * @param int $bookedConferenceID
     * @return mixed
     */
    public function getAllowedToAccess($bookedConferenceID)
    {
        $query = "SELECT user_id
                        FROM #__lms_conference_usr
                            WHERE p_id='".$bookedConferenceID."'";
        $this->db->setQuery( $query );
        return \JLMSDatabaseHelper::loadResultArray();
    }

    /**
     * Returns count of user who have access to enter specified conference
     *
     * @param int $bookedConferenceID
     * @return int
     */
    public function countAllowedToAccess($bookedConferenceID)
    {
        $query = "SELECT COUNT(user_id)
                        FROM #__lms_conference_usr
                            WHERE p_id='".$bookedConferenceID."'";
        $this->db->setQuery( $query );
        return $this->db->loadResult();
    }

    /**
     * Returns conference users (mostly used in views as a helper)
     *
     * @param int $bookedConferenceID
     * @return array
     */
    public function getAll($bookedConferenceID)
    {
        $query = "SELECT a.user_id, b.name, b.username
                    FROM
                        #__lms_conference_usr as a,
                        #__users as b
                    WHERE
                        a.p_id = '".$bookedConferenceID."'
                    AND
                        b.id = a.user_id";
        $this->db->setQuery($query);
        return $this->db->loadObjectList();
    }

    /**
     *
     * Returns list of users who have no access to con
     *
     * @param int $courseID
     * @param $userWithAccessToConference
     * @return mixed
     */
    public function getCourseUsersWithoutAccessToConference($courseID, $userWithAccessToConference)
    {
        $query = "SELECT a.*
                        FROM #__users as a,
                            #__lms_users_in_groups as b,
                            #__lms_usertypes as c
                        WHERE
                            a.id = b.user_id
                        AND
                            b.role_id = c.id
                        AND
                            b.course_id = '".$courseID."'"
            . ($userWithAccessToConference ? " AND a.id NOT IN (".$userWithAccessToConference.")" : '')
            . " GROUP BY a.id ORDER BY a.username, a.name";
        $this->db->setQuery($query);
        return  $this->db->LoadObjectList();
    }

    /**
     * Return userdata for user specified by username
     *
     * @param string $username
     * @return mixed
     */
    public function getInfo($username)
    {
        $query = "SELECT id, username, email
                    FROM #__users
                        WHERE username=".$this->db->quote($username);
        $this->db->setQuery($query);
        return $this->db->loadObject();
    }


    /**
     * Delete specified users from specified booked conference
     *
     * @param int $bookedConferenceID
     * @param array $userIDs
     * @return mixed
     */
    public function deleteFromConference($bookedConferenceID, $userIDs)
    {
        $query = "DELETE FROM #__lms_conference_usr WHERE p_id = '".$bookedConferenceID."' AND user_id IN (".implode( ',', $userIDs ).")";
        $this->db->setQuery($query);
        return $this->db->query();
    }

    /**
     * Delete user from specified booked conferences
     *
     * @param array $bookedConferenceIDs
     * @return mixed
     */
    public function deleteAllFromBookedConferences($bookedConferenceIDs)
    {
        $implodedBookedConferenceIDs = implode( ',', $bookedConferenceIDs );
        $query = "DELETE FROM #__lms_conference_usr WHERE p_id IN (".$implodedBookedConferenceIDs .")";
        $this->db->setQuery($query);
        return $this->db->query();

    }

	protected function beforeSave(&$data)
	{
		$this->prepareData($data);
	}

	protected function prepareData(&$data)
	{
		$data['p_id'] = $data['bookedConferenceID'];
		$data['user_id'] = $data['sel_user'];
        $data['id'] = false;
	}
}